@@ -153,14 +153,44 @@ gst_vaapi_decoder_vp9_create (GstVaapiDecoder * base_decoder)
   return TRUE;
 }
 
+/* Returns GstVaapiProfile from VP9 frame_hdr profile value */
+static GstVaapiProfile
+get_profile (guint profile_idc)
+{
+  GstVaapiProfile profile;
+
+  switch (profile_idc) {
+    case GST_VP9_PROFILE_0:
+      profile = GST_VAAPI_PROFILE_VP9_0;
+      break;
+    case GST_VP9_PROFILE_1:
+      profile = GST_VAAPI_PROFILE_VP9_1;
+      break;
+    case GST_VP9_PROFILE_2:
+      profile = GST_VAAPI_PROFILE_VP9_2;
+      break;
+    case GST_VP9_PROFILE_3:
+      profile = GST_VAAPI_PROFILE_VP9_3;
+      break;
+    default:
+      g_debug ("unsupported profile_idc value");
+      profile = GST_VAAPI_PROFILE_UNKNOWN;
+      break;
+  }
+  return profile;
+}
+
 static GstVaapiDecoderStatus
 ensure_context (GstVaapiDecoderVp9 * decoder)
 {
   GstVaapiDecoderVp9Private *const priv = &decoder->priv;
-  const GstVaapiProfile profile = GST_VAAPI_PROFILE_VP9;
+  GstVp9FrameHdr *frame_hdr = &priv->frame_hdr;
+  GstVaapiProfile profile;
   const GstVaapiEntrypoint entrypoint = GST_VAAPI_ENTRYPOINT_VLD;
   gboolean reset_context = FALSE;
 
+  profile = get_profile (frame_hdr->profile);
+
   if (priv->profile != profile) {
     if (!gst_vaapi_display_has_decoder (GST_VAAPI_DECODER_DISPLAY (decoder),
             profile, entrypoint))
@@ -190,6 +220,9 @@ ensure_context (GstVaapiDecoderVp9 * decoder)
 
     if (!reset_context)
       return GST_VAAPI_DECODER_STATUS_ERROR_UNKNOWN;
+
+    gst_vaapi_context_reset_on_resize (GST_VAAPI_DECODER_CONTEXT (decoder),
+        FALSE);
   }
   return GST_VAAPI_DECODER_STATUS_SUCCESS;
 }
@@ -261,8 +294,8 @@ fill_picture (GstVaapiDecoderVp9 * decoder, GstVaapiPicture * picture)
 #define COPY_BFM(a, s, f) \
     pic_param->a.bits.f = (s)->f
 
-  COPY_BFM (pic_fields, frame_hdr, subsampling_x);
-  COPY_BFM (pic_fields, frame_hdr, subsampling_y);
+  COPY_BFM (pic_fields, parser, subsampling_x);
+  COPY_BFM (pic_fields, parser, subsampling_y);
   COPY_BFM (pic_fields, frame_hdr, frame_type);
   COPY_BFM (pic_fields, frame_hdr, show_frame);
   COPY_BFM (pic_fields, frame_hdr, error_resilient_mode);
@@ -290,8 +323,9 @@ fill_picture (GstVaapiDecoderVp9 * decoder, GstVaapiPicture * picture)
   COPY_FIELD (frame_hdr, first_partition_size);
   COPY_FIELD (frame_hdr, profile);
 #if VA_CHECK_VERSION (0, 39, 0)
-  COPY_FIELD (frame_hdr, bit_depth);
+  COPY_FIELD (parser, bit_depth);
 #endif
+
   g_assert (G_N_ELEMENTS (pic_param->mb_segment_tree_probs) ==
       G_N_ELEMENTS (parser->mb_segment_tree_probs));
   g_assert (G_N_ELEMENTS (pic_param->segment_pred_probs) ==
@@ -566,9 +600,10 @@ parse_frame_header (GstVaapiDecoderVp9 * decoder, const guchar * buf,
     return get_status (result);
 
   /* Unlike other decoders, vp9 decoder doesn't need to reset the
-   * whole context and surfaces for each resolution change. context
-   * reset only needed if resolution of any frame is greater than
-   * what actullay configured. There are streams where a bigger
+   * whole context and surfaces for each resolution change. Calling
+   * ensure_context() again is only needed if the resolution of any frame
+   * is greater than what was previously configured, so that new, larger
+   * surfaces can be allocated. There are streams where a bigger
    * resolution set in ivf header or webm header but actual resolution
    * of all frames are less. Also it is possible to have inter-prediction
    * between these multi resolution frames */
